# KEYS API Documentation

**Total Endpoints**: 6

---

## 1. GET /api/v1/keys/

**Summary:** Get Keys

**Operation ID:** `get_keys_api_v1_keys__get`

---

## 2. GET /api/v1/keys/by_organization

**Summary:** Get Keys

**Operation ID:** `get_keys_api_v1_keys_by_organization_get`

### Parameters

- **organization_id** (query, Required) - Type: string

---

## 3. GET /api/v1/keys/organization_members_keys

**Summary:** Get Organization Members Keys

**Operation ID:** `get_organization_members_keys_api_v1_keys_organization_members_keys_get`

### Parameters

- **organization_id** (query, Required) - Type: string

---

## 4. GET /api/v1/keys/store

**Summary:** Get Key Store

**Operation ID:** `get_key_store_api_v1_keys_store_get`

### Parameters

- **api_key** (query, Required) - Type: string

---

## 5. GET /api/v1/keys/user

**Summary:** Get Key Store

**Operation ID:** `get_key_store_api_v1_keys_user_get`

### Parameters

- **api_key** (query, Required) - Type: string

---

## 6. POST /api/v1/keys/sync-usages

**Summary:** Sync Usages

**Operation ID:** `sync_usages_api_v1_keys_sync_usages_post`

### Request Body

**Status:** Required

---

